@@ -7,5 +7,5 @@ use tokio::io;
 
 #[async_trait]
 pub trait AsyncLineReader {
-    async fn next_line(&mut self) -> io::Result<Option<String>>;
+    async fn next_line(&mut self) -> io::Result<Option<Vec<String>>>;
 }
