@@ -5,9 +5,11 @@ pub struct LineInfo {
     pub dots: usize,
     pub double_quotes: usize,
     pub equals: usize,
-    pub slashes: usize,
     pub left_bracket: usize,
     pub right_bracket: usize,
+    pub slashes: usize,
+    pub zeros: usize,
+    pub x: usize,
 }
 
 impl LineInfo {
@@ -17,9 +19,11 @@ impl LineInfo {
         let mut dots = 0;
         let mut double_quotes = 0;
         let mut equals = 0;
-        let mut slashes = 0;
         let mut left_bracket = 0;
         let mut right_bracket = 0;
+        let mut slashes = 0;
+        let mut zeros = 0;
+        let mut x = 0;
 
         for c in line.chars() {
             match c {
@@ -31,6 +35,8 @@ impl LineInfo {
                 '/' => slashes += 1,
                 '[' => left_bracket += 1,
                 ']' => right_bracket += 1,
+                '0' => zeros += 1,
+                'x' | 'X' => x += 1,
                 _ => {}
             }
         }
@@ -44,6 +50,8 @@ impl LineInfo {
             colons,
             left_bracket,
             right_bracket,
+            zeros,
+            x,
         }
     }
 }
